cofe.wrangling package
======================

Submodules
----------

cofe.wrangling.select module
----------------------------

.. automodule:: cofe.wrangling.select
   :members:
   :undoc-members:
   :show-inheritance:

cofe.wrangling.tools module
---------------------------

.. automodule:: cofe.wrangling.tools
   :members:
   :undoc-members:
   :show-inheritance:

cofe.wrangling.wrangler module
------------------------------

.. automodule:: cofe.wrangling.wrangler
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cofe.wrangling
   :members:
   :undoc-members:
   :show-inheritance:
